@@ -1,7 +1,7 @@
 package Git::Bunch;
 
 our $DATE = '2016-06-14'; # DATE
-our $VERSION = '0.51'; # VERSION
+our $VERSION = '0.52'; # VERSION
 
 use 5.010001;
 use strict;
@@ -109,7 +109,7 @@ interested in recent repos (which is most of the time unless you are doing a
 full check/sync).
 
 _
-        schema => ['date*', 'x.perl.coerce_to' => 'DateTime', 'x.perl.coerce_rules' => ['str_alami_en']],
+        schema => ['date*', 'x.perl.coerce_rules' => ['str_alami_en']],
         tags => ['filter'],
     },
 );
@@ -235,7 +235,7 @@ sub _skip_process_entry {
             return 1;
         }
         my $min_rat = $args->{min_repo_access_time};
-        if ($min_rat && max(grep {defined} $e->{mtime}, $e->{commit_time}, $e->{status_time}, $e->{pull_time}) < $min_rat->epoch) {
+        if ($min_rat && max(grep {defined} $e->{mtime}, $e->{commit_time}, $e->{status_time}, $e->{pull_time}) < $min_rat) {
             $log->debug("Skipped $e->{name} (doesn't pass min_repo_access_time)");
             return 1;
         }
@@ -987,7 +987,7 @@ Git::Bunch - Manage gitbunch directory (directory which contain git repos)
 
 =head1 VERSION
 
-This document describes version 0.51 of Git::Bunch (from Perl distribution Git-Bunch), released on 2016-06-14.
+This document describes version 0.52 of Git::Bunch (from Perl distribution Git-Bunch), released on 2016-06-14.
 
 =head1 SYNOPSIS
 
